# -*- coding: utf-8 -*-
"""Module init-file.

The __init__.py files are required to make Python treat directories
containing the file as packages.
"""
from gold_python.automata import *
from gold_python.delta import *
